@@ -40,14 +40,16 @@ expect_error(boottest(object = lm_fit, clustid =  "group_id1", B = 999, seed = 9
 expect_error(boottest(object = feols_fit, clustid = c("group_id1"), B = 999, seed = 911, param = "treatment1", conf_int = TRUE))
 expect_error(boottest(object = felm_fit, clustid =  "group_id1", B = 999, seed = 911, param = "treatment1", conf_int = TRUE))
 
-# rademacher & mammen draws (full enumeration case)
+# rademacher enumeration case
 expect_warning(boottest(object = lm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE))
 expect_warning(boottest(object = feols_fit, clustid = c("group_id1"), B = 9999, seed = 911, param = "treatment", conf_int = TRUE))
 expect_warning(boottest(object = felm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE))
 
-expect_warning(boottest(object = lm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
-expect_warning(boottest(object = feols_fit, clustid = c("group_id1"), B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
-expect_warning(boottest(object = felm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
+expect_warning(boottest(object = lm_fit, clustid =  "group_id1", B = 2^10, seed = 911, param = "treatment", conf_int = TRUE))
+
+#expect_warning(boottest(object = lm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
+#expect_warning(boottest(object = feols_fit, clustid = c("group_id1"), B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
+#expect_warning(boottest(object = felm_fit, clustid =  "group_id1", B = 9999, seed = 911, param = "treatment", conf_int = TRUE, type = "mammen"))
 
 
 # test for banned function arguments and syntax for fixest
@@ -301,18 +303,7 @@ expect_warning(
     conf_int = FALSE)
 )
 
-# no confidence intervals calculated: expect warning
-expect_warning(
-  boottest(
-    object = lm_fit, 
-    clustid =  "group_id1", 
-    # guarantees that full enumeration is employed
-    B = 2^4 + 1, 
-    seed = 1, 
-    param = "treatment", 
-    type = "mammen",
-    conf_int = FALSE)
-)
+
 
 # with confidence intervals: expect_error because B < 100
 expect_error(
